==> org.eclipse.smartmdsd.xtext.service.componentMode.ui.source_3.7.0.202110191307.jar: org/eclipse/smartmdsd/xtext/service/componentMode/ui/ComponentModeExecutableExtensionFactory.java <==
/********************************************************************************
 * Copyright (c) 2017 Technische Hochschule Ulm, Servicerobotics Ulm, Germany
 * headed by Prof. Dr. Christian Schlegel
 * 
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0 which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 * 
 * SPDX-License-Identifier: EPL-2.0
 * 
 * Contributors:
 *   Alex Lotz, Dennis Stampfer, Matthias Lutz
 ********************************************************************************/
package org.eclipse.smartmdsd.xtext.service.componentMode.ui;

import com.google.inject.Injector;
import org.eclipse.core.runtime.Platform;
import org.eclipse.smartmdsd.xtext.service.componentMode.ui.internal.ComponentModeActivator;
import org.eclipse.xtext.ui.guice.AbstractGuiceAwareExecutableExtensionFactory;
import org.osgi.framework.Bundle;

/**
 * This class was generated. Customizations should only happen in a newly
 * introduced subclass. 
 */
public class ComponentModeExecutableExtensionFactory extends AbstractGuiceAwareExecutableExtensionFactory {

	@Override
	protected Bundle getBundle() {
		return Platform.getBundle(ComponentModeActivator.PLUGIN_ID);
	}
	
	@Override
	protected Injector getInjector() {
		ComponentModeActivator activator = ComponentModeActivator.getInstance();
		return activator != null ? activator.getInjector(ComponentModeActivator.ORG_ECLIPSE_SMARTMDSD_XTEXT_SERVICE_COMPONENTMODE_COMPONENTMODE) : null;
	}

}

==> org.eclipse.smartmdsd.xtext.service.componentMode.ui.source_3.7.0.202204050609.jar: org/eclipse/smartmdsd/xtext/service/componentMode/ui/ComponentModeExecutableExtensionFactory.java <==
/********************************************************************************
 * Copyright (c) 2017 Technische Hochschule Ulm, Servicerobotics Ulm, Germany
 * headed by Prof. Dr. Christian Schlegel
 * 
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0 which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 * 
 * SPDX-License-Identifier: EPL-2.0
 * 
 * Contributors:
 *   Alex Lotz, Dennis Stampfer, Matthias Lutz
 ********************************************************************************/
package org.eclipse.smartmdsd.xtext.service.componentMode.ui;

import com.google.inject.Injector;
import org.eclipse.smartmdsd.xtext.service.componentMode.ui.internal.ComponentModeActivator;
import org.eclipse.xtext.ui.guice.AbstractGuiceAwareExecutableExtensionFactory;
import org.osgi.framework.Bundle;
import org.osgi.framework.FrameworkUtil;

/**
 * This class was generated. Customizations should only happen in a newly
 * introduced subclass. 
 */
public class ComponentModeExecutableExtensionFactory extends AbstractGuiceAwareExecutableExtensionFactory {

	@Override
	protected Bundle getBundle() {
		return FrameworkUtil.getBundle(ComponentModeActivator.class);
	}
	
	@Override
	protected Injector getInjector() {
		ComponentModeActivator activator = ComponentModeActivator.getInstance();
		return activator != null ? activator.getInjector(ComponentModeActivator.ORG_ECLIPSE_SMARTMDSD_XTEXT_SERVICE_COMPONENTMODE_COMPONENTMODE) : null;
	}

}
